system
---
**What can it do?**
___
>it based from downloader.You can make mods for it.Put mod file and lilbraries in to dic.The file name must equals class name.
---
>You can write word on it.
---
>after downloaded it,you can open the zip file "{path}/---.zip" and use it.


About Author
---
**Author's e-mail**
***
>email:guoxiuchen20170402@163.com









